import axios, { Axios, AxiosResponse } from "axios";
import {
  InterestRatesQueryRequest,
  InterestRatesResponse,
  LoanToValueQueryRequest,
  LoanToValueResponse,
} from "./schemas/information.schema";
import {
  CreateAccountQueryRequest,
  CreateAccountRequest,
  ReserveAccountQueryRequest,
  ReserveAccountResponse,
  AccountListResponse,
  TransactionListQueryRequest,
  TransactionListResponse
} from "./schemas/accounts.schema";

import {  
  ContactInformationRequest, 
  UpdateContactInformationRequestSchema, 
  UpdateContactInformationRequest,
  ContactDetailsResponse,
} from "./schemas/contacts.schema";

import { response } from "express";

/**
 * Reserve account
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function reserveAccount(
  query: ReserveAccountQueryRequest,
  baseUrl: string = "http://services-core"
): Promise<ReserveAccountResponse> {
  const response = await axios.post<any, AxiosResponse<ReserveAccountResponse>>(
    `${baseUrl}/api/accounts/reservation`,
    null,
    { params: query }
  );
  return response.data;
}

/**
 * Create account
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function createAccount(
  query: CreateAccountQueryRequest,
  data: CreateAccountRequest,
  baseUrl: string = "http://services-core"
): Promise<any> {
  const response = await axios.post<any, AxiosResponse<any>>(
    `${baseUrl}/api/accounts`,
    data,
    { params: query }
  );
  return response.data;
}

/**
 * Update contact information
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function updateContactInformation(
  query: UpdateContactInformationRequest,
  data: UpdateContactInformationRequest,
  baseUrl: string = "http://services-core"
): Promise<ContactDetailsResponse> {
  const response = await axios.post<any, AxiosResponse<ContactDetailsResponse>>(
    `${baseUrl}/api/contacts`,
    data,
    {params: query}
  );
  return response.data;
}


/**
 * Get interest rates
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getInterestRates(
  query: InterestRatesQueryRequest,
  baseUrl: string = "http://services-core"
): Promise<InterestRatesResponse> {
  const response = await axios.get<any, AxiosResponse<InterestRatesResponse>>(
    `${baseUrl}/api/information/interest-rates`,
    { params: query }
  );
  return response.data;
}

/**
 * Get loan to value
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getLoanToValue(
  query: LoanToValueQueryRequest,
  baseUrl: string = "http://services-core"
): Promise<LoanToValueResponse> {
  const response = await axios.get<any, AxiosResponse<LoanToValueResponse>>(
    `${baseUrl}/api/information/loan-to-value`,
    { params: query }
  );
  return response.data;
}

/**
 * Get account list
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getAccountList(
  baseUrl: string = "http://services-core"
): Promise<AccountListResponse> {
  const response = await axios.get<any, AxiosResponse<AccountListResponse>>(
    `${baseUrl}/api/accounts`,
  );
  return response.data
}
/**
 * Create account
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getAccountById(
  baseUrl: string = "http://services-core"
): Promise <AccountListResponse> {
  const response = await axios.get<any, AxiosResponse<AccountListResponse>>(
    `${baseUrl}/api/accounts/:accountNo/?${process.env.COUNTRY_ID}&${process.env.BUSINESS_AREA_ID}`,
  );

  return response.data
}

/**
 * Get transactions
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getTransactions(
  query: TransactionListQueryRequest,
  baseUrl: string = "http://services-core"
): Promise <TransactionListResponse> {
  const response = await axios.get<any, AxiosResponse<TransactionListResponse>>(
    `${baseUrl}/api/accounts/:accountNo/transactions`,
    {params: query}
  );
  return response.data
}

/**
 * Create account
 * @param baseUrl - Baseurl to service url @defaults to http://services-core
 */
export async function getContactInformation(
  query: ContactInformationRequest,
  baseUrl: string = "http://services-core"
): Promise<ContactDetailsResponse> {
  const response = await axios.get<any, AxiosResponse<ContactDetailsResponse>>(
    `${baseUrl}/api/contacts/legal-id/NO17059896083`,
    {params: query}
  );
  return response.data
}



export type {
  CreateAccountRequest,
  CreateAccountQueryRequest,
  ReserveAccountQueryRequest,
  ReserveAccountResponse,
  InterestRatesQueryRequest,
  InterestRatesResponse,
  LoanToValueQueryRequest,
  LoanToValueResponse,
  AccountListResponse,
  ContactInformationRequest,
  TransactionListQueryRequest,
};
